# WrfPyApp
![alt text](https://github.com/onurhdogan/WrfPyApp/blob/master/ctt.png)


WRF Data visualization with WrfPyApp.

WrfPyApp uses WRF-Python (https://github.com/NCAR/wrf-python/tree/master) package.

You could use WrfPyApp on your PC after installing necessary Python packages.

It aims to quick visualization and analyzing WRF Data. 

You could find the WrfPyApp.py first version executable file in the repository.

Tutorial Video link is below 

https://youtu.be/OOU85-5CM5w
